<?php
/*
	Plugin Name: Enable Database Tools
	Plugin URI: https://perishablepress.com/wordpress-plugin-enable-database-tools/
	Description: Enables you to optimize and repair InnoDB and MyISAM database tables using WordPress built-in database optimization tools.
	Tags: database, tools, innodb, myisam, tables, optimize, repair
	Author: Jeff Starr
	Author URI: https://plugin-planet.com/
	Donate link: https://monzillamedia.com/donate.html
	Contributors: specialk
	Requires at least: 4.6
	Tested up to: 6.0
	Stable tag: 2.4
	Version: 2.4
	Requires PHP: 5.6.20
	Text Domain: enable-database-tools
	Domain Path: /languages
	License: GPL v2 or later
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 
	2 of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	with this program. If not, visit: https://www.gnu.org/licenses/
	
	Copyright 2022 Monzilla Media. All rights reserved.
	
*/

if (!defined('ABSPATH')) exit;

if (!class_exists('EnableDatabaseTools')) {
	
	class EnableDatabaseTools {
		
		function __construct() {
			
			$this->constants();
			
			add_action('admin_menu',            array($this, 'add_menu'));
			add_filter('admin_init',            array($this, 'add_settings'));
			add_action('admin_init',            array($this, 'check_version'));
			add_filter('plugin_action_links',   array($this, 'action_links'), 10, 2);
			add_filter('plugin_row_meta',       array($this, 'plugin_links'), 10, 2);
			add_action('init',                  array($this, 'load_i18n'));
			
		} 
		
		function constants() {
			
			if (!defined('ENABLE_DATABASE_TOOLS_VERSION')) define('ENABLE_DATABASE_TOOLS_VERSION', '2.4');
			if (!defined('ENABLE_DATABASE_TOOLS_REQUIRE')) define('ENABLE_DATABASE_TOOLS_REQUIRE', '4.6');
			if (!defined('ENABLE_DATABASE_TOOLS_AUTHOR'))  define('ENABLE_DATABASE_TOOLS_AUTHOR',  'Jeff Starr');
			if (!defined('ENABLE_DATABASE_TOOLS_NAME'))    define('ENABLE_DATABASE_TOOLS_NAME',    __('Enable Database Tools', 'enable-database-tools'));
			if (!defined('ENABLE_DATABASE_TOOLS_HOME'))    define('ENABLE_DATABASE_TOOLS_HOME',    esc_url('https://perishablepress.com/wordpress-plugin-enable-database-tools/'));
			if (!defined('ENABLE_DATABASE_TOOLS_URL'))     define('ENABLE_DATABASE_TOOLS_URL',     plugin_dir_url(__FILE__));
			if (!defined('ENABLE_DATABASE_TOOLS_DIR'))     define('ENABLE_DATABASE_TOOLS_DIR',     plugin_dir_path(__FILE__));
			if (!defined('ENABLE_DATABASE_TOOLS_FILE'))    define('ENABLE_DATABASE_TOOLS_FILE',    plugin_basename(__FILE__));
			if (!defined('ENABLE_DATABASE_TOOLS_SLUG'))    define('ENABLE_DATABASE_TOOLS_SLUG',    basename(dirname(__FILE__)));
			
		}
		
		function add_menu() {
			
			$title_page = esc_html__('Enable Database Tools', 'enable-database-tools');
			$title_menu = esc_html__('Enable DB Tools', 'enable-database-tools');
			
			add_options_page($title_page, $title_menu, 'manage_options', 'enable-database-tools', array($this, 'display_settings'));
			
		}
		
		function add_settings() {
			
			register_setting('enable_db_tools_options', 'enable_db_tools_options', array($this, 'validate_settings'));
			
			add_settings_section('general', esc_html__('Plugin Usage', 'enable-database-tools'), array($this, 'section_general'), 'enable_db_tools_options');
			
			add_settings_field('enable_tools', esc_html__('Enable DB Tools', 'enable-database-tools'), array($this, 'callback_checkbox'),   'enable_db_tools_options', 'general', array('id' => 'enable_tools', 'label' => esc_html__('Enable database tools', 'enable-database-tools')));
			
			$options = get_option('enable_db_tools_options', $this->options());
			
			$enable = (isset($options['enable_tools']) && !empty($options['enable_tools'])) ? true : false;
			
			if ($enable) {
				
				add_settings_field('null_option',  esc_html__('Open DB Tools',   'enable-database-tools'), array($this, 'callback_tools_link'), 'enable_db_tools_options', 'general', array('id' => 'null_option',  'label' => esc_html__('Open database tools',   'enable-database-tools')));
				
			}
			
		}
		
		function action_links($links, $file) {
			
			if ($file === ENABLE_DATABASE_TOOLS_FILE && (current_user_can('manage_options'))) {
				
				$hhif_links = '<a href="'. admin_url('options-general.php?page=enable-database-tools') .'">'. esc_html__('Settings', 'enable-database-tools') .'</a>';
				
				array_unshift($links, $hhif_links);
				
			}
			
			return $links;
			
		}
		
		function plugin_links($links, $file) {
			
			if ($file === ENABLE_DATABASE_TOOLS_FILE) {
				
				$home_href  = 'https://perishablepress.com/wordpress-plugin-enable-database-tools/';
				$home_title = esc_attr__('Plugin Homepage', 'enable-database-tools');
				$home_text  = esc_html__('Homepage', 'enable-database-tools');
				
				$links[] = '<a target="_blank" rel="noopener noreferrer" href="'. $home_href .'" title="'. $home_title .'">'. $home_text .'</a>';
				
				$rate_href  = 'https://wordpress.org/support/plugin/'. ENABLE_DATABASE_TOOLS_SLUG .'/reviews/?rate=5#new-post';
				$rate_title = esc_attr__('Click here to rate and review this FREE plugin at WordPress.org!', 'enable-database-tools');
				$rate_text  = esc_html__('Rate this plugin', 'enable-database-tools') .'&nbsp;&raquo;';
				
				$links[]    = '<a target="_blank" rel="noopener noreferrer" href="'. $rate_href .'" title="'. $rate_title .'">'. $rate_text .'</a>';
				
			}
			
			return $links;
			
		}
		
		function check_version() {
			
			$wp_version = get_bloginfo('version');
			
			if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
				
				if (version_compare($wp_version, ENABLE_DATABASE_TOOLS_REQUIRE, '<')) {
					
					if (is_plugin_active(ENABLE_DATABASE_TOOLS_FILE)) {
						
						deactivate_plugins(ENABLE_DATABASE_TOOLS_FILE);
						
						$msg  = '<strong>'. ENABLE_DATABASE_TOOLS_NAME .'</strong> '. esc_html__('requires WordPress ', 'enable-database-tools') . ENABLE_DATABASE_TOOLS_REQUIRE;
						$msg .= esc_html__(' or higher, and has been deactivated! ', 'enable-database-tools');
						$msg .= esc_html__('Please return to the', 'enable-database-tools') .' <a href="'. admin_url() .'">';
						$msg .= esc_html__('WP Admin Area', 'enable-database-tools') .'</a> '. esc_html__('to upgrade WordPress and try again.', 'enable-database-tools');
						
						wp_die($msg);
						
					}
					
				}
				
			}
			
		}
		
		function load_i18n() {
			
			load_plugin_textdomain('enable-database-tools', false, dirname(plugin_basename(__FILE__)) .'/languages/');
			
		}
		
		function __clone() {
			
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&rsquo; huh?', 'enable-database-tools'), ENABLE_DATABASE_TOOLS_VERSION);
			
		}
		
		function __wakeup() {
			
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&rsquo; huh?', 'enable-database-tools'), ENABLE_DATABASE_TOOLS_VERSION);
			
		}
		
		function options() {
			
			$options = array(
				
				'enable_tools'  => false,
				
			);
			
			return apply_filters('enable_database_tools_default_options', $options);
			
		}
		
		function validate_settings($input) {
			
			if (isset($input['null_option'])) unset($input['null_option']);
			
			if (!isset($input['enable_tools'])) $input['enable_tools'] = null;
			$input['enable_tools'] = ($input['enable_tools'] == 1 ? 1 : 0);
			
			return $input;
			
		}
		
		function section_general() {
			
			echo '<p>'. esc_html__('Check the box to enable, uncheck to disable.', 'enable-database-tools') .'</p>';
			
			echo '<p><strong>'. esc_html__('IMPORTANT:', 'enable-database-tools') .'</strong> '. esc_html__('Remember to uncheck/disable after using the database tools!', 'enable-database-tools') .'</p>';
			
		}
		
		function display_settings() {
			
			?>
			
			<div class="wrap">
				<h1><?php echo ENABLE_DATABASE_TOOLS_NAME; ?></h1>
				<form method="post" action="options.php">
					
					<?php settings_fields('enable_db_tools_options'); ?>
					<?php do_settings_sections('enable_db_tools_options'); ?>
					<?php submit_button(); ?>
					
				</form>
			</div>
			
			<?php
			
		}
		
		function callback_checkbox($args) {
			
			$options = get_option('enable_db_tools_options', $this->options());
			
			$id    = isset($args['id'])    ? $args['id']    : '';
			$label = isset($args['label']) ? $args['label'] : '';
			
			$option = isset($options[$id]) ? $options[$id] : '';
			
			$checked = checked($option, 1, false);
			
			echo '<label><input '. $checked .' name="enable_db_tools_options['. esc_attr($id) .']" type="checkbox" value="1"> '. esc_html($label) .'</label>';
			
		}
		
		function callback_tools_link() {
			
			echo '<a target="_blank" rel="noopener noreferrer" href="'. admin_url('maint/repair.php') .'">'. esc_html__('Open WP Database Tools', 'enable-database-tools') .'&nbsp;&raquo;</a>';
			
		}
		
	}
	
	$EnableDatabaseTools = new EnableDatabaseTools(); 
	
	$EnableDatabaseTools_options = get_option('enable_db_tools_options', array('enable_tools' => false));
	
	$EnableDatabaseTools_enable = (isset($EnableDatabaseTools_options['enable_tools']) && !empty($EnableDatabaseTools_options['enable_tools'])) ? true : false;
	
	if ($EnableDatabaseTools_enable) define('WP_ALLOW_REPAIR', true);
	
}
